@@ -13,9 +13,21 @@ from a site like `CelesTrak <https://celestrak.com/>`_.
 
 .. _Fundamentals of Astrodynamics and Applications: https://celestrak.org/software/vallado-sw.php
 
+What we today call ‘SGP4’ in fact merges together what in the 1970s were
+originally two separate satellite propagation routines, but which are
+now selected automatically:
+
+* SGP4 — the ‘Simplified General Perturbations' model is used for
+  satellites close enough to Earth that their orbit takes less than
+  225 minutes (3 hours 45 minutes) to complete.
+
+* SDP4 — the ‘Simplified Deep Space Perturbations' model is used for
+  satellites farther from Earth, which take 225 minutes or longer to
+  compete an orbit.
+
 If your machine can’t install or compile the C++ code, then this package
-falls back to using a slower pure-Python implementation of SGP4.  Tests
-make sure that its positions **agree to within 0.1 mm** with the
+falls back to using a slower pure-Python implementation of the library.
+Tests make sure that its positions **agree to within 0.1 mm** with the
 standard version of the algorithm — an error far less than the
 1–3 km/day by which satellites themselves deviate from the ideal orbits
 described in TLE files.
@@ -78,7 +90,7 @@ As input, you can provide either:
   be consumed by the whole part that specifies the day.  The remaining
   digits will provide a precision for the fraction of around 20.1 µs.
   This should be no problem for the accuracy of your result — satellite
-  positions usually off by a few kilometers anyway, far less than a
+  positions are usually off by a few kilometers anyway, far less than a
   satellite moves in 20.1 µs — but if you run a solver that dives down
   into the microseconds while searching for a rising or setting time,
   the solver might be bothered by the 20.1 µs plateau between each jump
@@ -157,19 +169,30 @@ You can already try out experimental support for OMM:
 Reading OMM data takes two steps, because OMM supports several different
 text formats.  First, parse the input text to recover the field names
 and values that it stores; second, build a Python satellite object from
-those field values.  For example, to load OMM from XML:
-
->>> with open('sample_omm.xml') as f:
-...     fields = next(omm.parse_xml(f))
->>> sat = Satrec()
->>> omm.initialize(sat, fields)
-
-Or, to load OMM from CSV:
+those field values.  The fastest and most efficient format is usually
+CSV, since the column names are only given once, on the first line:
 
 >>> with open('sample_omm.csv') as f:
-...     fields = next(omm.parse_csv(f))
->>> sat = Satrec()
->>> omm.initialize(sat, fields)
+...     for fields in omm.parse_csv(f):
+...         sat = Satrec()
+...         omm.initialize(sat, fields)
+
+The JSON format is more verbose because it repeats the field names over
+again in every single record:
+
+>>> import json
+>>> with open('sample_omm.json') as f:
+...     record_list = json.load(f)
+>>> for fields in record_list:
+...     sat = Satrec()
+...     omm.initialize(sat, fields)
+
+The most verbose format is XML:
+
+>>> with open('sample_omm.xml') as f:
+...     for fields in omm.parse_xml(f):
+...         sat = Satrec()
+...         omm.initialize(sat, fields)
 
 Either way, the satellite object should wind up properly initialized and
 ready to start producing positions.
@@ -394,17 +417,26 @@ first code example above:
 ...     0.0,                  # ndot: ballistic coefficient (radians/minute^2)
 ...     0.0,                  # nddot: mean motion 2nd derivative (radians/minute^3)
 ...     0.0007417,            # ecco: eccentricity
-...     0.3083420829620822,   # argpo: argument of perigee (radians)
-...     0.9013560935706996,   # inclo: inclination (radians)
-...     1.4946964807494398,   # mo: mean anomaly (radians)
+...     0.3083420829620822,   # argpo: argument of perigee (radians 0..2pi)
+...     0.9013560935706996,   # inclo: inclination (radians 0..pi)
+...     1.4946964807494398,   # mo: mean anomaly (radians 0..2pi)
 ...     0.06763602333248933,  # no_kozai: mean motion (radians/minute)
-...     3.686137125541276,    # nodeo: R.A. of ascending node (radians)
+...     3.686137125541276,    # nodeo: R.A. of ascending node (radians 0..2pi)
 ... )
 
-These numbers don’t look the same as the numbers in the TLE, because the
-underlying ``sgp4init()`` routine uses different units: radians rather
-than degrees.  But this is the same orbit and will produce the same
-positions.
+You might notice that these numbers don’t look the same as the numbers
+in the TLE above.  For example, the inclination was 51.6439 in the TLE,
+but is 0.901356 here.  That’s because ``sgp4init()`` uses different
+units than the TLE format: angles are in radians rather than degrees.
+But this is the same orbit and will produce the same positions.
+
+If you want to double-check that your elements are valid, you can run
+the function ``check_satrec()``, which will raise a ``ValueError`` with
+an informative error message if any of the angles are out of bounds.  If
+the satellite is fine, it simply returns, without raising an exception:
+
+>>> from sgp4.conveniences import check_satrec
+>>> check_satrec(satellite2)
 
 Note that ``ndot`` and ``nddot`` are ignored by the SGP4 propagator, so
 you can leave them ``0.0`` without any effect on the resulting satellite
@@ -460,11 +492,11 @@ over again to propagate positions for different times.
 | ``nddot`` — Second time derivative of the mean motion
   (loaded from the TLE, but otherwise ignored).
 | ``bstar`` — Ballistic drag coefficient B* (1/earth radii).
-| ``inclo`` — Inclination (radians).
-| ``nodeo`` — Right ascension of ascending node (radians).
+| ``inclo`` — Inclination (radians 0 ≤ i < pi).
+| ``nodeo`` — Right ascension of ascending node (radians 0 ≤ Ω < 2pi).
 | ``ecco`` — Eccentricity.
-| ``argpo`` — Argument of perigee (radians).
-| ``mo`` — Mean anomaly (radians).
+| ``argpo`` — Argument of perigee (radians 0 ≤ ω < 2pi).
+| ``mo`` — Mean anomaly (radians 0 ≤ M < 2pi).
 | ``no_kozai`` — Mean motion (radians/minute).
 | ``no`` — Alias for ``no_kozai``, for compatibility with old code.
 
@@ -526,13 +558,13 @@ The possible ``error`` codes are:
 
 *Mean Elements From Most Recent Propagation*
 
-Partway through each propagation, the SGP4 routine saves a set of
-“singly averaged mean elements” that describe the orbit’s shape at the
-moment for which a position is being computed.  They are averaged with
-respect to the mean anomaly and include the effects of secular gravity,
-atmospheric drag, and — in Deep Space mode — of those pertubations from
-the Sun and Moon that SGP4 averages over an entire revolution of each of
-those bodies.  They omit both the shorter-term and longer-term periodic
+Each time the SGP4 routine generates a satellite position, it also saves
+a set of “singly averaged mean elements” that describe shape of the
+satellite's orbit at that moment.  They are averaged with respect to the
+mean anomaly and include the effects of secular gravity, atmospheric
+drag, and — in Deep Space mode — of those pertubations from the Sun and
+Moon that SGP4 averages over an entire revolution of each of those
+bodies.  They omit both the shorter-term and longer-term periodic
 pertubations from the Sun and Moon that SGP4 applies right before
 computing each position.
 
@@ -620,6 +652,18 @@ https://pypi.org/project/sgp4/1.4/
 Changelog
 ---------
 
+2024-02-15 — 2.24
+
+* The documentation now specifies the acceptable range for orbital
+  element angles like inclination and mean anomaly, and a new function
+  ``check_satrec(sat)`` will tell the caller if any of the angles are
+  out of bounds.
+
+* The documentation now gives an example of loading elements from JSON.
+
+* Tweaked the fallback Python code to accept TLE lines without a final
+  checksum character in the 69th column, to match the C++ code.
+
 2023-10-01 — 2.23
 
 * Tweaked tests to resolve breakage introduced by Python 3.12.
@@ -711,4 +755,4 @@ Changelog
 | 2012-08-27 — 1.0 — Initial release
 
 """
-__version__ = '2.23'
+__version__ = '2.24'
