@@ -2,7 +2,7 @@
 
 try:
     from unittest2 import TestCase, main
-except:
+except ImportError:
     from unittest import TestCase, main
 
 import datetime as dt
@@ -170,6 +170,16 @@ def test_sat_epoch_datetime():
     zone = conveniences.UTC
     assertEqual(datetime, dt.datetime(2000, 6, 27, 18, 50, 19, 733568, zone))
 
+def test_check_satrec():
+    sat = Satrec.twoline2rv(LINE1, LINE2)
+    conveniences.check_satrec(sat)  # should succeed with no exception
+
+    sat = Satrec.twoline2rv(LINE1, LINE2.replace('34.2682', '-4.2682'))
+    msg = ('satellite parameters out of range:\n'
+           '  inclo = -0.074494 is outside the range 0 <= inclo < pi')
+    with assertRaisesRegex(ValueError, msg):
+        conveniences.check_satrec(sat)
+
 def test_good_tle_checksum():
     for line in LINE1, LINE2:
         checksum = int(line[-1])
@@ -386,6 +396,12 @@ def test_1990s_satrec_initialized_with_sgp4init():
     )
     assertEqual(sat.epochyr, 99)
 
+def test_tle_that_lacks_checksums():
+    Satrec.twoline2rv(
+        '1 00058U 60013A   97142.85906518  .00000093  00000-0 +10762-4 0  274',
+        '2 00058 028.3286 356.4726 0164991 158.6392 202.1128 13.4602145880282',
+    )
+
 def test_setters():
     sat = Satrec()
 
